
# THIS FILE IS GENERATED FROM NUMPY SETUP.PY
#
# To compare versions robustly, use `numpy.lib.NumpyVersion`
short_version = '1.15.2'
version = '1.15.2'
full_version = '1.15.2'
git_revision = 'fc06722cbec8f4b1713824fad7e1da1acc1583f8'
release = True

if not release:
    version = full_version
